function yout=mam2c(Wzy,Mxxz,xin)

%
% Memória Associativa Morfológica de Duas Camadas
%    (Para padrões binários);
%
% Comando: xout=mam2c(Wzy,Mxxz,xin)
% 
% Entradas:
%       Wzy - Matriz da segunda camada,
%      Mxxz - Matriz dos pesos sinápticos da primeira camada,
%       xin - Padrão de entrada
%   
% Saídas:
%      yout - Padrão recordado pela memória associativa,
%

yout=boxmax(Wzy,ceil(boxmin(Mxxz,xin)/100));